==> haskell-safesemaphore-0.10.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SafeSemaphore
version: 0.10.1
id: SafeSemaphore-0.10.1-Hsx9QD1iCOD1T9wxULdiEa
key: SafeSemaphore-0.10.1-Hsx9QD1iCOD1T9wxULdiEa
license: BSD-3-Clause
maintainer: Chris Kuklewicz <haskell@list.mightyreason.com>
author: Chris Kuklewicz <haskell@list.mightyreason.com>
homepage: https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis: Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.
category: Concurrency
abi: 779ebe664652805b0b0deff92eb4c13e
exposed: True
exposed-modules:
    Control.Concurrent.FairRWLock Control.Concurrent.MSampleVar
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.SSem
    Control.Concurrent.STM.SSem
hidden-modules: Control.Concurrent.STM.SSemInternals
import-dirs: /usr/lib/ghc-8.4.3/site-local/SafeSemaphore-0.10.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/SafeSemaphore-0.10.1
hs-libraries: HSSafeSemaphore-0.10.1-Hsx9QD1iCOD1T9wxULdiEa
depends:
    base-4.11.1.0 containers-0.5.11.0 stm-2.4.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
haddock-interfaces: /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock
haddock-html: /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safesemaphore-0.10.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SafeSemaphore
version: 0.10.1
id: SafeSemaphore-0.10.1-5hPZYv5rQ3hJ92ouQ29rd4
key: SafeSemaphore-0.10.1-5hPZYv5rQ3hJ92ouQ29rd4
license: BSD-3-Clause
maintainer: Chris Kuklewicz <haskell@list.mightyreason.com>
author: Chris Kuklewicz <haskell@list.mightyreason.com>
homepage: https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis: Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.
category: Concurrency
abi: be692fb83e21ae73ec51074ced7d9403
exposed: True
exposed-modules:
    Control.Concurrent.FairRWLock Control.Concurrent.MSampleVar
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.SSem
    Control.Concurrent.STM.SSem
hidden-modules: Control.Concurrent.STM.SSemInternals
import-dirs: /usr/lib/ghc-8.6.1/site-local/SafeSemaphore-0.10.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/SafeSemaphore-0.10.1
hs-libraries: HSSafeSemaphore-0.10.1-5hPZYv5rQ3hJ92ouQ29rd4
depends:
    base-4.12.0.0 containers-0.6.0.1 stm-2.5.0.0
haddock-interfaces: /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock
haddock-html: /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
